cmoncrawl.aggregator.utils.ndjson\_decoder.Decoder.raw\_decode
==============================================================

.. currentmodule:: cmoncrawl.aggregator.utils.ndjson_decoder

.. automethod:: Decoder.raw_decode